@@ -41,7 +41,7 @@ class HltMkab(BaseModel):
     type_doc = models.ForeignKey('OmsTypedoc', models.DO_NOTHING, db_column='rf_TYPEDOCID')
     s_doc = models.CharField(db_column='S_DOC', max_length=10)
     n_doc = models.CharField(db_column='N_DOC', max_length=15)
-    tip_oms = models.ForeignKey('OmsKlTipOms', models.DO_NOTHING, db_column='rf_kl_TipOMSID')
+    tip_oms = models.ForeignKey('OmsKlTipOms', models.DO_NOTHING, related_name='+', db_column='rf_kl_TipOMSID')
     s_pol = models.CharField(db_column='S_POL', max_length=50)
     n_pol = models.CharField(db_column='N_POL', max_length=50)
     is_worker = models.BooleanField(db_column='IsWorker')
